==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/user/messages/th/account.php <==
<?php

return [
    '<strong>Account</strong> settings' => 'การตั้งค่า<strong>บัญชี</strong>',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>ยืนยัน</strong> ที่อยู่อีเมลใหม่ของคุณ',
    '<strong>Permissions</strong>' => '<strong>การอนุญาต</strong>',
    '<strong>User</strong> modules' => '<strong>ผู้ใช้</strong> โมดูล',
    '<strong>User</strong> settings' => 'การตั้งค่า<strong>ผู้ใช้</strong>',
    '<strong>Your</strong> profile' => '<strong>โปรไฟล์ของคุณ</strong>',
    'All your personal data will be irrevocably deleted.' => 'ข้อมูลส่วนบุคคลทั้งหมดของคุณจะถูกลบโดยไม่สามารถเพิกถอนได้',
    'Are you really sure? *ALL* module data for your profile will be deleted!' => 'คุณแน่ใจจริงๆเหรอ? ข้อมูลโมดูล *ทั้งหมด* สำหรับโปรไฟล์ของคุณจะถูกลบ!',
    'Are you sure that you want to delete your account?' => 'คุณแน่ใจหรือไม่ว่าต้องการลบบัญชีของคุณ',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'การเปลี่ยนชื่อผู้ใช้อาจทำให้บางลิงก์ใช้ไม่ได้ เช่น ลิงก์เก่าไปยังโปรไฟล์',
    'Configure' => 'กำหนดค่า',
    'Confirm' => 'ยืนยัน',
    'Current password' => 'รหัสผ่านปัจจุบัน',
    'Delete account' => 'ลบบัญชี',
    'Disable' => 'ปิดการใช้งาน',
    'Do you really want to delete your icon image?' => 'คุณต้องการลบภาพไอคอนของคุณจริงๆ หรือไม่?',
    'Do you really want to delete your logo image?' => 'คุณต้องการลบภาพโลโก้ของคุณจริงๆ หรือไม่?',
    'E-Mail' => 'อีเมล',
    'E-Mail change' => 'เปลี่ยนอีเมล',
    'Enable' => 'เปิดใช้งาน',
    'Enhance your profile with modules.' => 'ปรับปรุงโปรไฟล์ของคุณด้วยโมดูล',
    'Enter your password to continue' => 'ป้อนรหัสผ่านเพื่อดำเนินการต่อ',
    'Hello' => 'สวัสดี',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'คุณสามารถแก้ไขข้อมูลโปรไฟล์ทั่วไปได้ที่นี่ ซึ่งจะปรากฏในหน้าเกี่ยวกับของโปรไฟล์ของคุณ',
    'Hide introduction tour panel on dashboard' => 'ซ่อนแผงการทัวร์แนะนำบนแดชบอร์ด',
    'Invalid link! Please make sure that you entered the entire url.' => 'ลิงค์ไม่ถูกต้อง! โปรดตรวจสอบให้แน่ใจว่าคุณป้อน URL ทั้งหมด',
    'Language' => 'ภาษา',
    'Modules' => 'โมดูล',
    'New E-Mail address' => 'ที่อยู่อีเมลใหม่',
    'New User name' => 'ชื่อผู้ใช้ใหม่',
    'Not registered users' => 'ไม่ใช่ผู้ใช้ที่ลงทะเบียน',
    'Notifications' => 'การแจ้งเตือน',
    'Other users' => 'ผู้ใช้รายอื่น',
    'Password Recovery' => 'รหัสผ่าน',
    'Permissions' => 'สิทธิ์',
    'Profile' => 'ข้อมูลส่วนตัว',
    'Profile visibility' => 'การเปิดเผยโปรไฟล์',
    'Registered users only' => 'ผู้ใช้ที่ลงทะเบียนเท่านั้น',
    'Save' => 'บันทึก',
    'Save profile' => 'จัดเก็บรายละเอียด',
    'Settings' => 'การตั้งค่า',
    'Tags' => 'แท็ก',
    'The entered e-mail address is already in use by another user.' => 'ที่อยู่อีเมลที่ป้อนถูกใช้โดยผู้ใช้รายอื่นแล้ว',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'การตั้งค่าเหล่านี้ช่วยให้คุณกำหนดได้ว่าคุณต้องการให้สิทธิ์ใดแก่ผู้เยี่ยมชมโปรไฟล์ของคุณเอง ผู้ใช้แต่ละคนสามารถปรับการตั้งค่าสำหรับโปรไฟล์ของตนเองได้อย่างอิสระ',
    'TimeZone' => 'เขตเวลา',
    'Username has been changed' => 'ชื่อผู้ใช้มีการเปลี่ยนแปลง',
    'Users' => 'ผู้ใช้',
    'Visible for all (also unregistered users)' => 'ปรากฏแก่ทุกคน (รวมถึงผู้ใช้ที่ไม่ได้ลงทะเบียนด้วย)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'เราเพิ่งส่งอีเมลยืนยันไปยังที่อยู่ใหม่ของคุณ <br> โปรดปฏิบัติตามคำแนะนำด้านใน',
    'You are currently the owner of following spaces:' => 'คุณเป็นเจ้าของพื้นที่ต่อไปนี้:',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'คุณเป็นเจ้าของพื้นที่ต่อไปนี้:
คุณได้ร้องขอให้เปลี่ยนที่อยู่อีเมลของคุณ<br>ที่อยู่อีเมลใหม่ของคุณคือ {newemail}.<br><br>เพื่อยืนยันที่อยู่อีเมลใหม่ของคุณ โปรดคลิกที่ปุ่มด้านล่าง',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'คุณเปลี่ยนชื่อผู้ใช้สำเร็จแล้ว<br>ชื่อผู้ใช้ใหม่ของคุณคือ {newUsername}',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'คุณต้องโอนความเป็นเจ้าของหรือลบพื้นที่เหล่านี้ก่อนจึงจะสามารถลบบัญชีของคุณได้',
    'Your account cannot be deleted!' => 'บัญชีของคุณไม่สามารถลบได้!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'บัญชีของคุณไม่สามารถลบได้!
ที่อยู่อีเมลปัจจุบันของคุณคือ <b>{email}</b> คุณสามารถเปลี่ยนที่อยู่อีเมลปัจจุบันของคุณได้ที่นี่',
    'Your current password can be changed here.' => 'รหัสผ่านปัจจุบันของคุณสามารถเปลี่ยนได้ที่นี่',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'ชื่อผู้ใช้ปัจจุบันของคุณคือ <b>{username}</b> คุณสามารถเปลี่ยนชื่อผู้ใช้ปัจจุบันของคุณได้ที่นี่',
    'Your e-mail address has been successfully changed to {email}.' => 'ที่อยู่อีเมลของคุณเปลี่ยนเป็น {email} สำเร็จแล้ว',
    'Your friends' => 'เพื่อนของคุณ',
    'Your password has been successfully changed!' => 'รหัสผ่านของคุณถูกเปลี่ยนเรียบร้อยแล้ว!',
    'Your username has been changed' => 'ชื่อผู้ใช้ของคุณมีการเปลี่ยนแปลง',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'ชื่อผู้ใช้ของคุณได้รับการเปลี่ยนเรียบร้อยแล้ว <br> เราเพิ่งส่งอีเมลแจ้งข้อมูลใหม่ถึงคุณ',
    '{attribute} "{value}" was not found!' => 'ไม่พบ {attribute} "{value}"!',
    'Blocked users' => '',
];

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/user/messages/th/account.php <==
<?php

return [
    '<strong>Confirm</strong></strong> your new email address' => '<strong>ยืนยัน</strong> ที่อยู่อีเมลใหม่ของคุณ',
    '<strong>Permissions</strong>' => '<strong>การอนุญาต</strong>',
    '<strong>Your</strong> profile' => '<strong>โปรไฟล์ของคุณ</strong>',
    'All your personal data will be irrevocably deleted.' => 'ข้อมูลส่วนบุคคลทั้งหมดของคุณจะถูกลบโดยไม่สามารถเพิกถอนได้',
    'Are you sure that you want to delete your account?' => 'คุณแน่ใจหรือไม่ว่าต้องการลบบัญชีของคุณ',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'การเปลี่ยนชื่อผู้ใช้อาจทำให้บางลิงก์ใช้ไม่ได้ เช่น ลิงก์เก่าไปยังโปรไฟล์',
    'Confirm' => 'ยืนยัน',
    'Current password' => 'รหัสผ่านปัจจุบัน',
    'Delete account' => 'ลบบัญชี',
    'Do you really want to delete your icon image?' => 'คุณต้องการลบภาพไอคอนของคุณจริงๆ หรือไม่?',
    'Do you really want to delete your logo image?' => 'คุณต้องการลบภาพโลโก้ของคุณจริงๆ หรือไม่?',
    'E-Mail' => 'อีเมล',
    'E-Mail change' => 'เปลี่ยนอีเมล',
    'Enter your password to continue' => 'ป้อนรหัสผ่านเพื่อดำเนินการต่อ',
    'Hello' => 'สวัสดี',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'คุณสามารถแก้ไขข้อมูลโปรไฟล์ทั่วไปได้ที่นี่ ซึ่งจะปรากฏในหน้าเกี่ยวกับของโปรไฟล์ของคุณ',
    'Hide introduction tour panel on dashboard' => 'ซ่อนแผงการทัวร์แนะนำบนแดชบอร์ด',
    'Invalid link! Please make sure that you entered the entire url.' => 'ลิงค์ไม่ถูกต้อง! โปรดตรวจสอบให้แน่ใจว่าคุณป้อน URL ทั้งหมด',
    'Language' => 'ภาษา',
    'Modules' => 'โมดูล',
    'New E-Mail address' => 'ที่อยู่อีเมลใหม่',
    'New User name' => 'ชื่อผู้ใช้ใหม่',
    'Not registered users' => 'ไม่ใช่ผู้ใช้ที่ลงทะเบียน',
    'Notifications' => 'การแจ้งเตือน',
    'Other users' => 'ผู้ใช้รายอื่น',
    'Password Recovery' => 'รหัสผ่าน',
    'Permissions' => 'สิทธิ์',
    'Profile' => 'ข้อมูลส่วนตัว',
    'Profile visibility' => 'การเปิดเผยโปรไฟล์',
    'Registered users only' => 'ผู้ใช้ที่ลงทะเบียนเท่านั้น',
    'Save' => 'บันทึก',
    'Save profile' => 'จัดเก็บรายละเอียด',
    'The entered e-mail address is already in use by another user.' => 'ที่อยู่อีเมลที่ป้อนถูกใช้โดยผู้ใช้รายอื่นแล้ว',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'การตั้งค่าเหล่านี้ช่วยให้คุณกำหนดได้ว่าคุณต้องการให้สิทธิ์ใดแก่ผู้เยี่ยมชมโปรไฟล์ของคุณเอง ผู้ใช้แต่ละคนสามารถปรับการตั้งค่าสำหรับโปรไฟล์ของตนเองได้อย่างอิสระ',
    'TimeZone' => 'เขตเวลา',
    'Username has been changed' => 'ชื่อผู้ใช้มีการเปลี่ยนแปลง',
    'Users' => 'ผู้ใช้',
    'Visible for all (also unregistered users)' => 'ปรากฏแก่ทุกคน (รวมถึงผู้ใช้ที่ไม่ได้ลงทะเบียนด้วย)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'เราเพิ่งส่งอีเมลยืนยันไปยังที่อยู่ใหม่ของคุณ <br> โปรดปฏิบัติตามคำแนะนำด้านใน',
    'You are currently the owner of following spaces:' => 'คุณเป็นเจ้าของพื้นที่ต่อไปนี้:',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'คุณเป็นเจ้าของพื้นที่ต่อไปนี้:
คุณได้ร้องขอให้เปลี่ยนที่อยู่อีเมลของคุณ<br>ที่อยู่อีเมลใหม่ของคุณคือ {newemail}.<br><br>เพื่อยืนยันที่อยู่อีเมลใหม่ของคุณ โปรดคลิกที่ปุ่มด้านล่าง',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'คุณเปลี่ยนชื่อผู้ใช้สำเร็จแล้ว<br>ชื่อผู้ใช้ใหม่ของคุณคือ {newUsername}',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'คุณต้องโอนความเป็นเจ้าของหรือลบพื้นที่เหล่านี้ก่อนจึงจะสามารถลบบัญชีของคุณได้',
    'Your account cannot be deleted!' => 'บัญชีของคุณไม่สามารถลบได้!',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'บัญชีของคุณไม่สามารถลบได้!
ที่อยู่อีเมลปัจจุบันของคุณคือ <b>{email}</b> คุณสามารถเปลี่ยนที่อยู่อีเมลปัจจุบันของคุณได้ที่นี่',
    'Your current password can be changed here.' => 'รหัสผ่านปัจจุบันของคุณสามารถเปลี่ยนได้ที่นี่',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'ชื่อผู้ใช้ปัจจุบันของคุณคือ <b>{username}</b> คุณสามารถเปลี่ยนชื่อผู้ใช้ปัจจุบันของคุณได้ที่นี่',
    'Your e-mail address has been successfully changed to {email}.' => 'ที่อยู่อีเมลของคุณเปลี่ยนเป็น {email} สำเร็จแล้ว',
    'Your friends' => 'เพื่อนของคุณ',
    'Your password has been successfully changed!' => 'รหัสผ่านของคุณถูกเปลี่ยนเรียบร้อยแล้ว!',
    'Your username has been changed' => 'ชื่อผู้ใช้ของคุณมีการเปลี่ยนแปลง',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'ชื่อผู้ใช้ของคุณได้รับการเปลี่ยนเรียบร้อยแล้ว <br> เราเพิ่งส่งอีเมลแจ้งข้อมูลใหม่ถึงคุณ',
    '{attribute} "{value}" was not found!' => 'ไม่พบ {attribute} "{value}"!',
    '<strong>Account</strong> Settings' => '',
    '<strong>User</strong> Account' => '',
    'Account Settings' => '',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => '',
    'Blocked users' => '',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => '',
    'Profile Tags' => '',
    'You cannot use this username.' => '',
];
